# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: c37.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='c37.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\tc37.proto\x12\x06xbospb\"\x91\x01\n\x0c\x43\x33\x37\x44\x61taFrame\x12\x13\n\x0bstationName\x18\x01 \x01(\t\x12\x0e\n\x06idCode\x18\x02 \x01(\r\x12-\n\x0ephasorChannels\x18\x03 \x03(\x0b\x32\x15.xbospb.PhasorChannel\x12-\n\x0escalarChannels\x18\x04 \x03(\x0b\x32\x15.xbospb.ScalarChannel\"P\n\rPhasorChannel\x12\x13\n\x0b\x63hannelName\x18\x01 \x01(\t\x12\x0c\n\x04unit\x18\x02 \x01(\t\x12\x1c\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x0e.xbospb.Phasor\"N\n\x06Phasor\x12\x0c\n\x04time\x18\x01 \x01(\x03\x12\r\n\x05\x61ngle\x18\x02 \x01(\x01\x12\x11\n\tmagnitude\x18\x03 \x01(\x01\x12\t\n\x01P\x18\x04 \x01(\x01\x12\t\n\x01Q\x18\x05 \x01(\x01\"P\n\rScalarChannel\x12\x13\n\x0b\x63hannelName\x18\x01 \x01(\t\x12\x0c\n\x04unit\x18\x02 \x01(\t\x12\x1c\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x0e.xbospb.Scalar\"%\n\x06Scalar\x12\x0c\n\x04time\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x01\x62\x06proto3')
)




_C37DATAFRAME = _descriptor.Descriptor(
  name='C37DataFrame',
  full_name='xbospb.C37DataFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stationName', full_name='xbospb.C37DataFrame.stationName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='idCode', full_name='xbospb.C37DataFrame.idCode', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phasorChannels', full_name='xbospb.C37DataFrame.phasorChannels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scalarChannels', full_name='xbospb.C37DataFrame.scalarChannels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=167,
)


_PHASORCHANNEL = _descriptor.Descriptor(
  name='PhasorChannel',
  full_name='xbospb.PhasorChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channelName', full_name='xbospb.PhasorChannel.channelName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='xbospb.PhasorChannel.unit', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='xbospb.PhasorChannel.data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=249,
)


_PHASOR = _descriptor.Descriptor(
  name='Phasor',
  full_name='xbospb.Phasor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.Phasor.time', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='angle', full_name='xbospb.Phasor.angle', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='magnitude', full_name='xbospb.Phasor.magnitude', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='P', full_name='xbospb.Phasor.P', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Q', full_name='xbospb.Phasor.Q', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=329,
)


_SCALARCHANNEL = _descriptor.Descriptor(
  name='ScalarChannel',
  full_name='xbospb.ScalarChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channelName', full_name='xbospb.ScalarChannel.channelName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='xbospb.ScalarChannel.unit', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='xbospb.ScalarChannel.data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=411,
)


_SCALAR = _descriptor.Descriptor(
  name='Scalar',
  full_name='xbospb.Scalar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.Scalar.time', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='xbospb.Scalar.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=450,
)

_C37DATAFRAME.fields_by_name['phasorChannels'].message_type = _PHASORCHANNEL
_C37DATAFRAME.fields_by_name['scalarChannels'].message_type = _SCALARCHANNEL
_PHASORCHANNEL.fields_by_name['data'].message_type = _PHASOR
_SCALARCHANNEL.fields_by_name['data'].message_type = _SCALAR
DESCRIPTOR.message_types_by_name['C37DataFrame'] = _C37DATAFRAME
DESCRIPTOR.message_types_by_name['PhasorChannel'] = _PHASORCHANNEL
DESCRIPTOR.message_types_by_name['Phasor'] = _PHASOR
DESCRIPTOR.message_types_by_name['ScalarChannel'] = _SCALARCHANNEL
DESCRIPTOR.message_types_by_name['Scalar'] = _SCALAR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

C37DataFrame = _reflection.GeneratedProtocolMessageType('C37DataFrame', (_message.Message,), dict(
  DESCRIPTOR = _C37DATAFRAME,
  __module__ = 'c37_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.C37DataFrame)
  ))
_sym_db.RegisterMessage(C37DataFrame)

PhasorChannel = _reflection.GeneratedProtocolMessageType('PhasorChannel', (_message.Message,), dict(
  DESCRIPTOR = _PHASORCHANNEL,
  __module__ = 'c37_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.PhasorChannel)
  ))
_sym_db.RegisterMessage(PhasorChannel)

Phasor = _reflection.GeneratedProtocolMessageType('Phasor', (_message.Message,), dict(
  DESCRIPTOR = _PHASOR,
  __module__ = 'c37_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Phasor)
  ))
_sym_db.RegisterMessage(Phasor)

ScalarChannel = _reflection.GeneratedProtocolMessageType('ScalarChannel', (_message.Message,), dict(
  DESCRIPTOR = _SCALARCHANNEL,
  __module__ = 'c37_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.ScalarChannel)
  ))
_sym_db.RegisterMessage(ScalarChannel)

Scalar = _reflection.GeneratedProtocolMessageType('Scalar', (_message.Message,), dict(
  DESCRIPTOR = _SCALAR,
  __module__ = 'c37_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Scalar)
  ))
_sym_db.RegisterMessage(Scalar)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hamilton.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hamilton.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0ehamilton.proto\x12\x06xbospb\"\\\n\x0cHamiltonData\x12\x0e\n\x06serial\x18\x01 \x01(\r\x12\r\n\x05model\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\x04\x12\x1f\n\x03h3c\x18\x04 \x01(\x0b\x32\x12.xbospb.Hamilton3C\"\x95\x02\n\nHamilton3C\x12\x0e\n\x06uptime\x18\x01 \x01(\x04\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\r\n\x05\x61\x63\x63_x\x18\x03 \x01(\x01\x12\r\n\x05\x61\x63\x63_y\x18\x04 \x01(\x01\x12\r\n\x05\x61\x63\x63_z\x18\x05 \x01(\x01\x12\r\n\x05mag_x\x18\x06 \x01(\x01\x12\r\n\x05mag_y\x18\x07 \x01(\x01\x12\r\n\x05mag_z\x18\x08 \x01(\x01\x12\x0f\n\x07tmp_die\x18\t \x01(\x01\x12\x13\n\x0btmp_voltage\x18\n \x01(\x01\x12\x10\n\x08\x61ir_temp\x18\x0b \x01(\x01\x12\x0f\n\x07\x61ir_hum\x18\x0c \x01(\x01\x12\x0e\n\x06\x61ir_rh\x18\r \x01(\x01\x12\x11\n\tlight_lux\x18\x0e \x01(\x01\x12\x0f\n\x07\x62uttons\x18\x0f \x01(\r\x12\x11\n\toccupancy\x18\x10 \x01(\x01\"\x96\x02\n\x0bHamilton330\x12\x0e\n\x06uptime\x18\x01 \x01(\x04\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\r\n\x05\x61\x63\x63_x\x18\x03 \x01(\x01\x12\r\n\x05\x61\x63\x63_y\x18\x04 \x01(\x01\x12\r\n\x05\x61\x63\x63_z\x18\x05 \x01(\x01\x12\r\n\x05mag_x\x18\x06 \x01(\x01\x12\r\n\x05mag_y\x18\x07 \x01(\x01\x12\r\n\x05mag_z\x18\x08 \x01(\x01\x12\x0f\n\x07tmp_die\x18\t \x01(\x01\x12\x13\n\x0btmp_voltage\x18\n \x01(\x01\x12\x10\n\x08\x61ir_temp\x18\x0b \x01(\x01\x12\x0f\n\x07\x61ir_hum\x18\x0c \x01(\x01\x12\x0e\n\x06\x61ir_rh\x18\r \x01(\x01\x12\x11\n\tlight_lux\x18\x0e \x01(\x01\x12\x0f\n\x07\x62uttons\x18\x0f \x01(\r\x12\x11\n\toccupancy\x18\x10 \x01(\x01\"\x8c\x02\n\x13HamiltonBRLinkStats\x12\x11\n\tBadFrames\x18\x01 \x01(\x04\x12\x12\n\nLostFrames\x18\x02 \x01(\x04\x12\x18\n\x10\x44ropNotConnected\x18\x03 \x01(\x04\x12\x19\n\x11SumSerialReceived\x18\x04 \x01(\x04\x12\x1a\n\x12SumDomainForwarded\x18\x05 \x01(\x04\x12\x1b\n\x13SumDropNotConnected\x18\x06 \x01(\x04\x12\x19\n\x11SumDomainReceived\x18\x07 \x01(\x04\x12\x1a\n\x12SumSerialForwarded\x18\x08 \x01(\x04\x12\x13\n\x0bPublishOkay\x18\t \x01(\x04\x12\x14\n\x0cPublishError\x18\n \x01(\x04\"\x8e\x01\n\x11HamiltonBRMessage\x12\x0e\n\x06SrcMAC\x18\x01 \x01(\t\x12\r\n\x05SrcIP\x18\x02 \x01(\t\x12\r\n\x05PopID\x18\x03 \x01(\t\x12\x0f\n\x07PopTime\x18\x04 \x01(\x03\x12\x0e\n\x06\x42RTime\x18\x05 \x01(\x03\x12\x0c\n\x04RSSI\x18\x06 \x01(\x05\x12\x0b\n\x03LQI\x18\x07 \x01(\x05\x12\x0f\n\x07Payload\x18\x08 \x01(\x0c\x62\x06proto3')
)




_HAMILTONDATA = _descriptor.Descriptor(
  name='HamiltonData',
  full_name='xbospb.HamiltonData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial', full_name='xbospb.HamiltonData.serial', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='xbospb.HamiltonData.model', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.HamiltonData.time', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='h3c', full_name='xbospb.HamiltonData.h3c', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=118,
)


_HAMILTON3C = _descriptor.Descriptor(
  name='Hamilton3C',
  full_name='xbospb.Hamilton3C',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uptime', full_name='xbospb.Hamilton3C.uptime', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='xbospb.Hamilton3C.flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acc_x', full_name='xbospb.Hamilton3C.acc_x', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acc_y', full_name='xbospb.Hamilton3C.acc_y', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acc_z', full_name='xbospb.Hamilton3C.acc_z', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mag_x', full_name='xbospb.Hamilton3C.mag_x', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mag_y', full_name='xbospb.Hamilton3C.mag_y', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mag_z', full_name='xbospb.Hamilton3C.mag_z', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmp_die', full_name='xbospb.Hamilton3C.tmp_die', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmp_voltage', full_name='xbospb.Hamilton3C.tmp_voltage', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='air_temp', full_name='xbospb.Hamilton3C.air_temp', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='air_hum', full_name='xbospb.Hamilton3C.air_hum', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='air_rh', full_name='xbospb.Hamilton3C.air_rh', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='light_lux', full_name='xbospb.Hamilton3C.light_lux', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buttons', full_name='xbospb.Hamilton3C.buttons', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occupancy', full_name='xbospb.Hamilton3C.occupancy', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=398,
)


_HAMILTON330 = _descriptor.Descriptor(
  name='Hamilton330',
  full_name='xbospb.Hamilton330',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uptime', full_name='xbospb.Hamilton330.uptime', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='xbospb.Hamilton330.flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acc_x', full_name='xbospb.Hamilton330.acc_x', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acc_y', full_name='xbospb.Hamilton330.acc_y', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acc_z', full_name='xbospb.Hamilton330.acc_z', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mag_x', full_name='xbospb.Hamilton330.mag_x', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mag_y', full_name='xbospb.Hamilton330.mag_y', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mag_z', full_name='xbospb.Hamilton330.mag_z', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmp_die', full_name='xbospb.Hamilton330.tmp_die', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmp_voltage', full_name='xbospb.Hamilton330.tmp_voltage', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='air_temp', full_name='xbospb.Hamilton330.air_temp', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='air_hum', full_name='xbospb.Hamilton330.air_hum', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='air_rh', full_name='xbospb.Hamilton330.air_rh', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='light_lux', full_name='xbospb.Hamilton330.light_lux', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buttons', full_name='xbospb.Hamilton330.buttons', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occupancy', full_name='xbospb.Hamilton330.occupancy', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=679,
)


_HAMILTONBRLINKSTATS = _descriptor.Descriptor(
  name='HamiltonBRLinkStats',
  full_name='xbospb.HamiltonBRLinkStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='BadFrames', full_name='xbospb.HamiltonBRLinkStats.BadFrames', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='LostFrames', full_name='xbospb.HamiltonBRLinkStats.LostFrames', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='DropNotConnected', full_name='xbospb.HamiltonBRLinkStats.DropNotConnected', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SumSerialReceived', full_name='xbospb.HamiltonBRLinkStats.SumSerialReceived', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SumDomainForwarded', full_name='xbospb.HamiltonBRLinkStats.SumDomainForwarded', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SumDropNotConnected', full_name='xbospb.HamiltonBRLinkStats.SumDropNotConnected', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SumDomainReceived', full_name='xbospb.HamiltonBRLinkStats.SumDomainReceived', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SumSerialForwarded', full_name='xbospb.HamiltonBRLinkStats.SumSerialForwarded', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PublishOkay', full_name='xbospb.HamiltonBRLinkStats.PublishOkay', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PublishError', full_name='xbospb.HamiltonBRLinkStats.PublishError', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=950,
)


_HAMILTONBRMESSAGE = _descriptor.Descriptor(
  name='HamiltonBRMessage',
  full_name='xbospb.HamiltonBRMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='SrcMAC', full_name='xbospb.HamiltonBRMessage.SrcMAC', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SrcIP', full_name='xbospb.HamiltonBRMessage.SrcIP', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PopID', full_name='xbospb.HamiltonBRMessage.PopID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PopTime', full_name='xbospb.HamiltonBRMessage.PopTime', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='BRTime', full_name='xbospb.HamiltonBRMessage.BRTime', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='RSSI', full_name='xbospb.HamiltonBRMessage.RSSI', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='LQI', full_name='xbospb.HamiltonBRMessage.LQI', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Payload', full_name='xbospb.HamiltonBRMessage.Payload', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=953,
  serialized_end=1095,
)

_HAMILTONDATA.fields_by_name['h3c'].message_type = _HAMILTON3C
DESCRIPTOR.message_types_by_name['HamiltonData'] = _HAMILTONDATA
DESCRIPTOR.message_types_by_name['Hamilton3C'] = _HAMILTON3C
DESCRIPTOR.message_types_by_name['Hamilton330'] = _HAMILTON330
DESCRIPTOR.message_types_by_name['HamiltonBRLinkStats'] = _HAMILTONBRLINKSTATS
DESCRIPTOR.message_types_by_name['HamiltonBRMessage'] = _HAMILTONBRMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HamiltonData = _reflection.GeneratedProtocolMessageType('HamiltonData', (_message.Message,), dict(
  DESCRIPTOR = _HAMILTONDATA,
  __module__ = 'hamilton_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.HamiltonData)
  ))
_sym_db.RegisterMessage(HamiltonData)

Hamilton3C = _reflection.GeneratedProtocolMessageType('Hamilton3C', (_message.Message,), dict(
  DESCRIPTOR = _HAMILTON3C,
  __module__ = 'hamilton_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Hamilton3C)
  ))
_sym_db.RegisterMessage(Hamilton3C)

Hamilton330 = _reflection.GeneratedProtocolMessageType('Hamilton330', (_message.Message,), dict(
  DESCRIPTOR = _HAMILTON330,
  __module__ = 'hamilton_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Hamilton330)
  ))
_sym_db.RegisterMessage(Hamilton330)

HamiltonBRLinkStats = _reflection.GeneratedProtocolMessageType('HamiltonBRLinkStats', (_message.Message,), dict(
  DESCRIPTOR = _HAMILTONBRLINKSTATS,
  __module__ = 'hamilton_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.HamiltonBRLinkStats)
  ))
_sym_db.RegisterMessage(HamiltonBRLinkStats)

HamiltonBRMessage = _reflection.GeneratedProtocolMessageType('HamiltonBRMessage', (_message.Message,), dict(
  DESCRIPTOR = _HAMILTONBRMESSAGE,
  __module__ = 'hamilton_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.HamiltonBRMessage)
  ))
_sym_db.RegisterMessage(HamiltonBRMessage)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: wavemq.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import eapi_pb2 as eapi__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='wavemq.proto',
  package='mqpb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0cwavemq.proto\x12\x04mqpb\x1a\neapi.proto\"\x18\n\x16\x43onnectionStatusParams\"F\n\x18\x43onnectionStatusResponse\x12\x12\n\ntotalPeers\x18\x01 \x01(\x05\x12\x16\n\x0e\x63onnectedPeers\x18\x02 \x01(\x05\"m\n\x0bQueryParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\x12\x11\n\tnamespace\x18\x02 \x01(\x0c\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x16\n\x0e\x63ustomProofDER\x18\x04 \x01(\x0c\"J\n\x0cQueryMessage\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x1e\n\x07message\x18\x02 \x01(\x0b\x32\r.mqpb.Message\"l\n\x0fPeerQueryParams\x12\x14\n\x0csourceEntity\x18\x01 \x01(\x0c\x12\x11\n\tnamespace\x18\x02 \x01(\x0c\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x11\n\tsignature\x18\x04 \x01(\x0c\x12\x10\n\x08proofDER\x18\x05 \x01(\x0c\"9\n\x15PeerUnsubscribeParams\x12\x14\n\x0csourceEntity\x18\x01 \x01(\x0c\x12\n\n\x02id\x18\x02 \x01(\t\"5\n\x17PeerUnsubscribeResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\"/\n\x11PeerPublishParams\x12\x1a\n\x03msg\x18\x01 \x01(\x0b\x32\r.mqpb.Message\"1\n\x13PeerPublishResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\"y\n\x13PeerSubscriptionTBS\x12\x14\n\x0csourceEntity\x18\x01 \x01(\x0c\x12\x11\n\tnamespace\x18\x02 \x01(\x0c\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x10\n\x08routerID\x18\x05 \x01(\t\x12\x0e\n\x06\x65xpiry\x18\x06 \x01(\x03\"z\n\x13PeerSubscribeParams\x12&\n\x03tbs\x18\x01 \x01(\x0b\x32\x19.mqpb.PeerSubscriptionTBS\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12\x10\n\x08proofDER\x18\x03 \x01(\x0c\x12\x16\n\x0e\x61\x62soluteExpiry\x18\x04 \x01(\x03\"\xc3\x01\n\rPublishParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\x12\x11\n\tnamespace\x18\x02 \x01(\x0c\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12$\n\x07\x63ontent\x18\x04 \x03(\x0b\x32\x13.mqpb.PayloadObject\x12\x1b\n\x13\x65ncryptionPartition\x18\x05 \x03(\x0c\x12\x0f\n\x07persist\x18\x06 \x01(\x08\x12\x16\n\x0e\x63ustomProofDER\x18\x07 \x01(\x0c\"-\n\x0fPublishResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\"\xa9\x01\n\nMessageTBS\x12\x14\n\x0csourceEntity\x18\x01 \x01(\x0c\x12)\n\x0esourceLocation\x18\x02 \x01(\x0b\x32\x11.mqpb.LocationURI\x12\x11\n\tnamespace\x18\x03 \x01(\x0c\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12$\n\x07payload\x18\x05 \x03(\x0b\x32\x13.mqpb.PayloadObject\x12\x14\n\x0coriginRouter\x18\x06 \x01(\t\"\xcd\x01\n\x07Message\x12\x1a\n\x05proof\x18\x01 \x01(\x0b\x32\x0b.mqpb.Proof\x12\x10\n\x08proofDER\x18\x02 \x01(\x0c\x12\x1d\n\x03tbs\x18\x03 \x01(\x0b\x32\x10.mqpb.MessageTBS\x12\x11\n\tsignature\x18\x04 \x01(\x0c\x12\x1b\n\x13\x65ncryptionPartition\x18\x05 \x03(\x0c\x12\x12\n\ntimestamps\x18\x06 \x03(\x03\x12\r\n\x05\x64rops\x18\x07 \x03(\x03\x12\x0f\n\x07persist\x18\x08 \x01(\x08\x12\x11\n\tproofHash\x18\t \x01(\x0c\"0\n\rPayloadObject\x12\x0e\n\x06schema\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"\xad\x01\n\x0fSubscribeParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\x12\x11\n\tnamespace\x18\x02 \x01(\x0c\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x16\n\x0e\x63ustomProofDER\x18\x04 \x01(\x0c\x12\x12\n\nidentifier\x18\x05 \x01(\t\x12\x0e\n\x06\x65xpiry\x18\x06 \x01(\x03\x12\x16\n\x0e\x61\x62soluteExpiry\x18\x07 \x01(\x03\"Q\n\x13SubscriptionMessage\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x1e\n\x07message\x18\x02 \x01(\x0b\x32\r.mqpb.Message2\x84\x02\n\x06WAVEMQ\x12\x35\n\x07Publish\x12\x13.mqpb.PublishParams\x1a\x15.mqpb.PublishResponse\x12?\n\tSubscribe\x12\x15.mqpb.SubscribeParams\x1a\x19.mqpb.SubscriptionMessage0\x01\x12\x30\n\x05Query\x12\x11.mqpb.QueryParams\x1a\x12.mqpb.QueryMessage0\x01\x12P\n\x10\x43onnectionStatus\x12\x1c.mqpb.ConnectionStatusParams\x1a\x1e.mqpb.ConnectionStatusResponse2\xab\x02\n\rWAVEMQPeering\x12\x41\n\x0bPeerPublish\x12\x17.mqpb.PeerPublishParams\x1a\x19.mqpb.PeerPublishResponse\x12G\n\rPeerSubscribe\x12\x19.mqpb.PeerSubscribeParams\x1a\x19.mqpb.SubscriptionMessage0\x01\x12M\n\x0fPeerUnsubscribe\x12\x1b.mqpb.PeerUnsubscribeParams\x1a\x1d.mqpb.PeerUnsubscribeResponse\x12?\n\x10PeerQueryRequest\x12\x15.mqpb.PeerQueryParams\x1a\x12.mqpb.QueryMessage0\x01\x62\x06proto3')
  ,
  dependencies=[eapi__pb2.DESCRIPTOR,])




_CONNECTIONSTATUSPARAMS = _descriptor.Descriptor(
  name='ConnectionStatusParams',
  full_name='mqpb.ConnectionStatusParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=58,
)


_CONNECTIONSTATUSRESPONSE = _descriptor.Descriptor(
  name='ConnectionStatusResponse',
  full_name='mqpb.ConnectionStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='totalPeers', full_name='mqpb.ConnectionStatusResponse.totalPeers', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connectedPeers', full_name='mqpb.ConnectionStatusResponse.connectedPeers', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=130,
)


_QUERYPARAMS = _descriptor.Descriptor(
  name='QueryParams',
  full_name='mqpb.QueryParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.QueryParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='mqpb.QueryParams.namespace', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='mqpb.QueryParams.uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customProofDER', full_name='mqpb.QueryParams.customProofDER', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=241,
)


_QUERYMESSAGE = _descriptor.Descriptor(
  name='QueryMessage',
  full_name='mqpb.QueryMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.QueryMessage.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='mqpb.QueryMessage.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=317,
)


_PEERQUERYPARAMS = _descriptor.Descriptor(
  name='PeerQueryParams',
  full_name='mqpb.PeerQueryParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sourceEntity', full_name='mqpb.PeerQueryParams.sourceEntity', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='mqpb.PeerQueryParams.namespace', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='mqpb.PeerQueryParams.uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='mqpb.PeerQueryParams.signature', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proofDER', full_name='mqpb.PeerQueryParams.proofDER', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=427,
)


_PEERUNSUBSCRIBEPARAMS = _descriptor.Descriptor(
  name='PeerUnsubscribeParams',
  full_name='mqpb.PeerUnsubscribeParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sourceEntity', full_name='mqpb.PeerUnsubscribeParams.sourceEntity', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='mqpb.PeerUnsubscribeParams.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=429,
  serialized_end=486,
)


_PEERUNSUBSCRIBERESPONSE = _descriptor.Descriptor(
  name='PeerUnsubscribeResponse',
  full_name='mqpb.PeerUnsubscribeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.PeerUnsubscribeResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=541,
)


_PEERPUBLISHPARAMS = _descriptor.Descriptor(
  name='PeerPublishParams',
  full_name='mqpb.PeerPublishParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg', full_name='mqpb.PeerPublishParams.msg', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=543,
  serialized_end=590,
)


_PEERPUBLISHRESPONSE = _descriptor.Descriptor(
  name='PeerPublishResponse',
  full_name='mqpb.PeerPublishResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.PeerPublishResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=641,
)


_PEERSUBSCRIPTIONTBS = _descriptor.Descriptor(
  name='PeerSubscriptionTBS',
  full_name='mqpb.PeerSubscriptionTBS',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sourceEntity', full_name='mqpb.PeerSubscriptionTBS.sourceEntity', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='mqpb.PeerSubscriptionTBS.namespace', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='mqpb.PeerSubscriptionTBS.uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='mqpb.PeerSubscriptionTBS.id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='routerID', full_name='mqpb.PeerSubscriptionTBS.routerID', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='mqpb.PeerSubscriptionTBS.expiry', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=643,
  serialized_end=764,
)


_PEERSUBSCRIBEPARAMS = _descriptor.Descriptor(
  name='PeerSubscribeParams',
  full_name='mqpb.PeerSubscribeParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tbs', full_name='mqpb.PeerSubscribeParams.tbs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='mqpb.PeerSubscribeParams.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proofDER', full_name='mqpb.PeerSubscribeParams.proofDER', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absoluteExpiry', full_name='mqpb.PeerSubscribeParams.absoluteExpiry', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=888,
)


_PUBLISHPARAMS = _descriptor.Descriptor(
  name='PublishParams',
  full_name='mqpb.PublishParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.PublishParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='mqpb.PublishParams.namespace', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='mqpb.PublishParams.uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='mqpb.PublishParams.content', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encryptionPartition', full_name='mqpb.PublishParams.encryptionPartition', index=4,
      number=5, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persist', full_name='mqpb.PublishParams.persist', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customProofDER', full_name='mqpb.PublishParams.customProofDER', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=891,
  serialized_end=1086,
)


_PUBLISHRESPONSE = _descriptor.Descriptor(
  name='PublishResponse',
  full_name='mqpb.PublishResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.PublishResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1088,
  serialized_end=1133,
)


_MESSAGETBS = _descriptor.Descriptor(
  name='MessageTBS',
  full_name='mqpb.MessageTBS',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sourceEntity', full_name='mqpb.MessageTBS.sourceEntity', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourceLocation', full_name='mqpb.MessageTBS.sourceLocation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='mqpb.MessageTBS.namespace', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='mqpb.MessageTBS.uri', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='mqpb.MessageTBS.payload', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='originRouter', full_name='mqpb.MessageTBS.originRouter', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1136,
  serialized_end=1305,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='mqpb.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='proof', full_name='mqpb.Message.proof', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proofDER', full_name='mqpb.Message.proofDER', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tbs', full_name='mqpb.Message.tbs', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='mqpb.Message.signature', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encryptionPartition', full_name='mqpb.Message.encryptionPartition', index=4,
      number=5, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='mqpb.Message.timestamps', index=5,
      number=6, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drops', full_name='mqpb.Message.drops', index=6,
      number=7, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persist', full_name='mqpb.Message.persist', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proofHash', full_name='mqpb.Message.proofHash', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1308,
  serialized_end=1513,
)


_PAYLOADOBJECT = _descriptor.Descriptor(
  name='PayloadObject',
  full_name='mqpb.PayloadObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schema', full_name='mqpb.PayloadObject.schema', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='mqpb.PayloadObject.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1515,
  serialized_end=1563,
)


_SUBSCRIBEPARAMS = _descriptor.Descriptor(
  name='SubscribeParams',
  full_name='mqpb.SubscribeParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.SubscribeParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='mqpb.SubscribeParams.namespace', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='mqpb.SubscribeParams.uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customProofDER', full_name='mqpb.SubscribeParams.customProofDER', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='mqpb.SubscribeParams.identifier', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='mqpb.SubscribeParams.expiry', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absoluteExpiry', full_name='mqpb.SubscribeParams.absoluteExpiry', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1566,
  serialized_end=1739,
)


_SUBSCRIPTIONMESSAGE = _descriptor.Descriptor(
  name='SubscriptionMessage',
  full_name='mqpb.SubscriptionMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.SubscriptionMessage.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='mqpb.SubscriptionMessage.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1741,
  serialized_end=1822,
)

_QUERYPARAMS.fields_by_name['perspective'].message_type = eapi__pb2._PERSPECTIVE
_QUERYMESSAGE.fields_by_name['error'].message_type = eapi__pb2._ERROR
_QUERYMESSAGE.fields_by_name['message'].message_type = _MESSAGE
_PEERUNSUBSCRIBERESPONSE.fields_by_name['error'].message_type = eapi__pb2._ERROR
_PEERPUBLISHPARAMS.fields_by_name['msg'].message_type = _MESSAGE
_PEERPUBLISHRESPONSE.fields_by_name['error'].message_type = eapi__pb2._ERROR
_PEERSUBSCRIBEPARAMS.fields_by_name['tbs'].message_type = _PEERSUBSCRIPTIONTBS
_PUBLISHPARAMS.fields_by_name['perspective'].message_type = eapi__pb2._PERSPECTIVE
_PUBLISHPARAMS.fields_by_name['content'].message_type = _PAYLOADOBJECT
_PUBLISHRESPONSE.fields_by_name['error'].message_type = eapi__pb2._ERROR
_MESSAGETBS.fields_by_name['sourceLocation'].message_type = eapi__pb2._LOCATIONURI
_MESSAGETBS.fields_by_name['payload'].message_type = _PAYLOADOBJECT
_MESSAGE.fields_by_name['proof'].message_type = eapi__pb2._PROOF
_MESSAGE.fields_by_name['tbs'].message_type = _MESSAGETBS
_SUBSCRIBEPARAMS.fields_by_name['perspective'].message_type = eapi__pb2._PERSPECTIVE
_SUBSCRIPTIONMESSAGE.fields_by_name['error'].message_type = eapi__pb2._ERROR
_SUBSCRIPTIONMESSAGE.fields_by_name['message'].message_type = _MESSAGE
DESCRIPTOR.message_types_by_name['ConnectionStatusParams'] = _CONNECTIONSTATUSPARAMS
DESCRIPTOR.message_types_by_name['ConnectionStatusResponse'] = _CONNECTIONSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['QueryParams'] = _QUERYPARAMS
DESCRIPTOR.message_types_by_name['QueryMessage'] = _QUERYMESSAGE
DESCRIPTOR.message_types_by_name['PeerQueryParams'] = _PEERQUERYPARAMS
DESCRIPTOR.message_types_by_name['PeerUnsubscribeParams'] = _PEERUNSUBSCRIBEPARAMS
DESCRIPTOR.message_types_by_name['PeerUnsubscribeResponse'] = _PEERUNSUBSCRIBERESPONSE
DESCRIPTOR.message_types_by_name['PeerPublishParams'] = _PEERPUBLISHPARAMS
DESCRIPTOR.message_types_by_name['PeerPublishResponse'] = _PEERPUBLISHRESPONSE
DESCRIPTOR.message_types_by_name['PeerSubscriptionTBS'] = _PEERSUBSCRIPTIONTBS
DESCRIPTOR.message_types_by_name['PeerSubscribeParams'] = _PEERSUBSCRIBEPARAMS
DESCRIPTOR.message_types_by_name['PublishParams'] = _PUBLISHPARAMS
DESCRIPTOR.message_types_by_name['PublishResponse'] = _PUBLISHRESPONSE
DESCRIPTOR.message_types_by_name['MessageTBS'] = _MESSAGETBS
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.message_types_by_name['PayloadObject'] = _PAYLOADOBJECT
DESCRIPTOR.message_types_by_name['SubscribeParams'] = _SUBSCRIBEPARAMS
DESCRIPTOR.message_types_by_name['SubscriptionMessage'] = _SUBSCRIPTIONMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConnectionStatusParams = _reflection.GeneratedProtocolMessageType('ConnectionStatusParams', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONSTATUSPARAMS,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.ConnectionStatusParams)
  ))
_sym_db.RegisterMessage(ConnectionStatusParams)

ConnectionStatusResponse = _reflection.GeneratedProtocolMessageType('ConnectionStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONSTATUSRESPONSE,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.ConnectionStatusResponse)
  ))
_sym_db.RegisterMessage(ConnectionStatusResponse)

QueryParams = _reflection.GeneratedProtocolMessageType('QueryParams', (_message.Message,), dict(
  DESCRIPTOR = _QUERYPARAMS,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.QueryParams)
  ))
_sym_db.RegisterMessage(QueryParams)

QueryMessage = _reflection.GeneratedProtocolMessageType('QueryMessage', (_message.Message,), dict(
  DESCRIPTOR = _QUERYMESSAGE,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.QueryMessage)
  ))
_sym_db.RegisterMessage(QueryMessage)

PeerQueryParams = _reflection.GeneratedProtocolMessageType('PeerQueryParams', (_message.Message,), dict(
  DESCRIPTOR = _PEERQUERYPARAMS,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.PeerQueryParams)
  ))
_sym_db.RegisterMessage(PeerQueryParams)

PeerUnsubscribeParams = _reflection.GeneratedProtocolMessageType('PeerUnsubscribeParams', (_message.Message,), dict(
  DESCRIPTOR = _PEERUNSUBSCRIBEPARAMS,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.PeerUnsubscribeParams)
  ))
_sym_db.RegisterMessage(PeerUnsubscribeParams)

PeerUnsubscribeResponse = _reflection.GeneratedProtocolMessageType('PeerUnsubscribeResponse', (_message.Message,), dict(
  DESCRIPTOR = _PEERUNSUBSCRIBERESPONSE,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.PeerUnsubscribeResponse)
  ))
_sym_db.RegisterMessage(PeerUnsubscribeResponse)

PeerPublishParams = _reflection.GeneratedProtocolMessageType('PeerPublishParams', (_message.Message,), dict(
  DESCRIPTOR = _PEERPUBLISHPARAMS,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.PeerPublishParams)
  ))
_sym_db.RegisterMessage(PeerPublishParams)

PeerPublishResponse = _reflection.GeneratedProtocolMessageType('PeerPublishResponse', (_message.Message,), dict(
  DESCRIPTOR = _PEERPUBLISHRESPONSE,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.PeerPublishResponse)
  ))
_sym_db.RegisterMessage(PeerPublishResponse)

PeerSubscriptionTBS = _reflection.GeneratedProtocolMessageType('PeerSubscriptionTBS', (_message.Message,), dict(
  DESCRIPTOR = _PEERSUBSCRIPTIONTBS,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.PeerSubscriptionTBS)
  ))
_sym_db.RegisterMessage(PeerSubscriptionTBS)

PeerSubscribeParams = _reflection.GeneratedProtocolMessageType('PeerSubscribeParams', (_message.Message,), dict(
  DESCRIPTOR = _PEERSUBSCRIBEPARAMS,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.PeerSubscribeParams)
  ))
_sym_db.RegisterMessage(PeerSubscribeParams)

PublishParams = _reflection.GeneratedProtocolMessageType('PublishParams', (_message.Message,), dict(
  DESCRIPTOR = _PUBLISHPARAMS,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.PublishParams)
  ))
_sym_db.RegisterMessage(PublishParams)

PublishResponse = _reflection.GeneratedProtocolMessageType('PublishResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUBLISHRESPONSE,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.PublishResponse)
  ))
_sym_db.RegisterMessage(PublishResponse)

MessageTBS = _reflection.GeneratedProtocolMessageType('MessageTBS', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGETBS,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.MessageTBS)
  ))
_sym_db.RegisterMessage(MessageTBS)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGE,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.Message)
  ))
_sym_db.RegisterMessage(Message)

PayloadObject = _reflection.GeneratedProtocolMessageType('PayloadObject', (_message.Message,), dict(
  DESCRIPTOR = _PAYLOADOBJECT,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.PayloadObject)
  ))
_sym_db.RegisterMessage(PayloadObject)

SubscribeParams = _reflection.GeneratedProtocolMessageType('SubscribeParams', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBEPARAMS,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.SubscribeParams)
  ))
_sym_db.RegisterMessage(SubscribeParams)

SubscriptionMessage = _reflection.GeneratedProtocolMessageType('SubscriptionMessage', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIPTIONMESSAGE,
  __module__ = 'wavemq_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.SubscriptionMessage)
  ))
_sym_db.RegisterMessage(SubscriptionMessage)



_WAVEMQ = _descriptor.ServiceDescriptor(
  name='WAVEMQ',
  full_name='mqpb.WAVEMQ',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1825,
  serialized_end=2085,
  methods=[
  _descriptor.MethodDescriptor(
    name='Publish',
    full_name='mqpb.WAVEMQ.Publish',
    index=0,
    containing_service=None,
    input_type=_PUBLISHPARAMS,
    output_type=_PUBLISHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='mqpb.WAVEMQ.Subscribe',
    index=1,
    containing_service=None,
    input_type=_SUBSCRIBEPARAMS,
    output_type=_SUBSCRIPTIONMESSAGE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Query',
    full_name='mqpb.WAVEMQ.Query',
    index=2,
    containing_service=None,
    input_type=_QUERYPARAMS,
    output_type=_QUERYMESSAGE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ConnectionStatus',
    full_name='mqpb.WAVEMQ.ConnectionStatus',
    index=3,
    containing_service=None,
    input_type=_CONNECTIONSTATUSPARAMS,
    output_type=_CONNECTIONSTATUSRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WAVEMQ)

DESCRIPTOR.services_by_name['WAVEMQ'] = _WAVEMQ


_WAVEMQPEERING = _descriptor.ServiceDescriptor(
  name='WAVEMQPeering',
  full_name='mqpb.WAVEMQPeering',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=2088,
  serialized_end=2387,
  methods=[
  _descriptor.MethodDescriptor(
    name='PeerPublish',
    full_name='mqpb.WAVEMQPeering.PeerPublish',
    index=0,
    containing_service=None,
    input_type=_PEERPUBLISHPARAMS,
    output_type=_PEERPUBLISHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PeerSubscribe',
    full_name='mqpb.WAVEMQPeering.PeerSubscribe',
    index=1,
    containing_service=None,
    input_type=_PEERSUBSCRIBEPARAMS,
    output_type=_SUBSCRIPTIONMESSAGE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PeerUnsubscribe',
    full_name='mqpb.WAVEMQPeering.PeerUnsubscribe',
    index=2,
    containing_service=None,
    input_type=_PEERUNSUBSCRIBEPARAMS,
    output_type=_PEERUNSUBSCRIBERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PeerQueryRequest',
    full_name='mqpb.WAVEMQPeering.PeerQueryRequest',
    index=3,
    containing_service=None,
    input_type=_PEERQUERYPARAMS,
    output_type=_QUERYMESSAGE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WAVEMQPEERING)

DESCRIPTOR.services_by_name['WAVEMQPeering'] = _WAVEMQPEERING

# @@protoc_insertion_point(module_scope)
